aboutsummaryrefslogtreecommitdiff
path: root/tools/boot
diff options
context:
space:
mode:
authorWarner Losh <imp@FreeBSD.org>2017-11-14 23:02:19 +0000
committerWarner Losh <imp@FreeBSD.org>2017-11-14 23:02:19 +0000
commitca987d4641cdcd7f27e153db17c5bf064934faf5 (patch)
tree6c3860e3ba8949be9528d644fbb7fa88d8bbbb79 /tools/boot
parent6eac7115560381ce5c9e2939ab3fce82bb9b6a95 (diff)
Notes
Diffstat (limited to 'tools/boot')
-rwxr-xr-xtools/boot/universe.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/boot/universe.sh b/tools/boot/universe.sh
index 3b607b4c4a1a2..495e84b1ebaa2 100755
--- a/tools/boot/universe.sh
+++ b/tools/boot/universe.sh
@@ -11,8 +11,8 @@
# powerpc/powerpc powerpc/powerpc64 powerpc/powerpcspe \
# riscv/riscv64 riscv/riscv64sf
#
# This script is expected to be run in sys/boot (though you could run it anywhere
# in the tree). It does a full clean build. For sys/boot you can do all the archs in
# about a minute or two on a fast machine. It's also possible that you need a full
# make universe for this to work completely.
#
@@ -40,7 +40,7 @@ dobuild()
}
top=$(make -V SRCTOP)
-cd $top/sys/boot
+cd $top/stand
# Default build for a goodly selection of architectures
for i in \
@@ -11,8 +11,8 @@
# riscv/riscv64 riscv/riscv64sf
#
-# This script is expected to be run in sys/boot (though you could run it anywhere
-# in the tree). It does a full clean build. For sys/boot you can do all the archs in
+# This script is expected to be run in stand (though you could run it anywhere
+# in the tree). It does a full clean build. For stand you can do all the archs in
# about a minute or two on a fast machine. It's also possible that you need a full
# make universe for this to work completely.